@@ -55,12 +55,12 @@ static bool m_inhibitHideBarTimer{false};
 
 std::unique_ptr<Core> Core::m_self;
 Core::Core(LinuxPackageType packageType, bool debugMode)
-    : audioThumbCache(QStringLiteral("audioCache"), 2000000)
+    : debugMode(debugMode)
+    , audioThumbCache(QStringLiteral("audioCache"), 2000000)
     , taskManager(this)
     , m_packageType(packageType)
     , m_capture(new MediaCapture(this))
     , sessionId(QUuid::createUuid().toString())
-    , debugMode(debugMode)
 {
     m_hideTimer.setInterval(5000);
     m_hideTimer.setSingleShot(true);
@@ -266,7 +266,7 @@ void Core::initGUI(const QString &MltPath, const QUrl &Url, const QStringList &c
             QMetaObject::invokeMethod(this, "cleanRestart", Qt::QueuedConnection, Q_ARG(bool, true));
         });
         connect(m_splash, &Splash::openBlank, this, [this]() {
-            if (m_splash->hasEventLoop()) {
+            if (m_splash->hasEventLoop() || !m_guiConstructed) {
                 connect(this, &Core::mainWindowReady, m_projectManager, &ProjectManager::slotLoadOnOpen, Qt::QueuedConnection);
             } else {
                 QMetaObject::invokeMethod(pCore->projectManager(), "slotLoadOnOpen", Qt::QueuedConnection);
@@ -276,9 +276,15 @@ void Core::initGUI(const QString &MltPath, const QUrl &Url, const QStringList &c
 
         // Check if welcome screen is displayed
         if (m_splash->welcomeDisplayed()) {
-            connect(this, &Core::closeSplash, m_splash, &Splash::hideAndDelete);
+            connect(this, &Core::closeSplash, this, [this]() {
+                disconnect(this, &Core::loadingMessageNewStage, m_splash, nullptr);
+                disconnect(this, &Core::closeSplash, this, nullptr);
+                m_splash->deleteLater();
+            });
             connect(m_splash, &Splash::openFile, this, [this](QString url) {
-                if (m_splash->hasEventLoop()) {
+                // Ensure this can only be called once
+                disconnect(m_splash, &Splash::openFile, this, nullptr);
+                if (m_splash->hasEventLoop() || !m_guiConstructed) {
                     connect(this, &Core::mainWindowReady, this, [&, url]() {
                         QMetaObject::invokeMethod(m_projectManager, "openFile", Qt::QueuedConnection, Q_ARG(QUrl, QUrl::fromLocalFile(url)));
                     });
@@ -287,14 +293,14 @@ void Core::initGUI(const QString &MltPath, const QUrl &Url, const QStringList &c
                 }
             });
             connect(m_splash, &Splash::openOtherFile, this, [this]() {
-                if (m_splash->hasEventLoop()) {
+                if (m_splash->hasEventLoop() || !m_guiConstructed) {
                     connect(this, &Core::mainWindowReady, [this]() { QMetaObject::invokeMethod(m_projectManager, "slotOpenFile", Qt::QueuedConnection); });
                 } else {
                     QMetaObject::invokeMethod(m_projectManager, "slotOpenFile", Qt::QueuedConnection);
                 }
             });
             connect(m_splash, &Splash::closeApp, this, [this]() {
-                if (m_splash->hasEventLoop()) {
+                if (m_splash->hasEventLoop() || !m_guiConstructed) {
                     QMetaObject::invokeMethod(this, "cleanRestart", Qt::QueuedConnection, Q_ARG(bool, false));
                 } else {
                     QFile lockFile(QDir::temp().absoluteFilePath(QStringLiteral("kdenlivelock")));
@@ -309,7 +315,7 @@ void Core::initGUI(const QString &MltPath, const QUrl &Url, const QStringList &c
 
             // History
             connect(m_splash, &Splash::clearHistory, this, [&]() {
-                if (m_splash->hasEventLoop()) {
+                if (m_splash->hasEventLoop() || !m_guiConstructed) {
                     connect(this, &Core::mainWindowReady, this, [&]() {
                         m_projectManager->recentFilesAction()->clear();
                         m_projectManager->recentFilesAction()->saveEntries(KConfigGroup(KSharedConfig::openConfig(), "Recent Files"));
@@ -320,7 +326,7 @@ void Core::initGUI(const QString &MltPath, const QUrl &Url, const QStringList &c
                 }
             });
             connect(m_splash, &Splash::forgetFile, this, [&](const QString path) {
-                if (m_splash->hasEventLoop()) {
+                if (m_splash->hasEventLoop() || !m_guiConstructed) {
                     connect(this, &Core::mainWindowReady, this, [&, path]() {
                         m_projectManager->recentFilesAction()->removeUrl(QUrl::fromLocalFile(path));
                         m_projectManager->recentFilesAction()->saveEntries(KConfigGroup(KSharedConfig::openConfig(), "Recent Files"));
@@ -349,26 +355,24 @@ void Core::initGUI(const QString &MltPath, const QUrl &Url, const QStringList &c
             connect(m_splash, &Splash::openTemplate, this, [this](QString url) {
                 if (url.isEmpty()) {
                     // Open project settings
-                    if (m_splash->hasEventLoop()) {
+                    if (m_splash->hasEventLoop() || !m_guiConstructed) {
                         connect(this, &Core::mainWindowReady, this, [&]() {
-                            m_splash->deleteLater();
                             m_mainWindow->show();
+                            m_splash->fadeOut();
                             QMetaObject::invokeMethod(m_projectManager, "newFile", Qt::QueuedConnection, Q_ARG(bool, true));
                         });
                     } else {
-                        m_splash->deleteLater();
                         m_mainWindow->show();
+                        m_splash->fadeOut();
                         m_projectManager->newFile(true);
                     }
                 } else {
-                    if (m_splash->hasEventLoop()) {
+                    if (m_splash->hasEventLoop() || !m_guiConstructed) {
                         connect(this, &Core::mainWindowReady, this, [&, url]() {
-                            m_splash->deleteLater();
                             m_mainWindow->show();
                             QMetaObject::invokeMethod(m_projectManager, "newFile", Qt::QueuedConnection, Q_ARG(QString, url), Q_ARG(bool, false));
                         });
                     } else {
-                        m_splash->deleteLater();
                         m_mainWindow->show();
                         m_projectManager->newFile(url, false);
                     }
@@ -381,11 +385,19 @@ void Core::initGUI(const QString &MltPath, const QUrl &Url, const QStringList &c
                     });
                 });
             } else {
-                connect(m_splash, &Splash::firstStart, this, &Core::startFromGuessedProfile);
+                connect(m_splash, &Splash::firstStart, this, [&](QString descriptiveString, QString fps, bool interlaced, int vTracks, int aTracks) {
+                    if (!guiReady()) {
+                        connect(this, &Core::mainWindowReady, this, [&, descriptiveString, fps, interlaced, vTracks, aTracks]() {
+                            startFromGuessedProfile(descriptiveString, fps, interlaced, vTracks, aTracks);
+                        });
+                    } else {
+                        startFromGuessedProfile(descriptiveString, fps, interlaced, vTracks, aTracks);
+                    }
+                });
             }
         } else {
             // Simple splash
-            connect(this, &Core::closeSplash, m_splash, &Splash::fadeOutAndDelete);
+            connect(this, &Core::closeSplash, m_splash, &Splash::fadeOutAndDelete, Qt::QueuedConnection);
             connect(this, &Core::loadingMessageNewStage, m_splash, &Splash::showProgressMessage, Qt::DirectConnection);
             /*QObject::connect(pCore.get(), &Core::loadingMessageNewStage, &splash, &Splash::showProgressMessage, Qt::DirectConnection);
             QObject::connect(pCore.get(), &Core::loadingMessageIncrease, &splash, &Splash::increaseProgressMessage, Qt::DirectConnection);
@@ -502,7 +514,7 @@ void Core::initGUI(const QString &MltPath, const QUrl &Url, const QStringList &c
     connect(this, &Core::displayBinMessage, this, &Core::displayBinMessagePrivate);
     connect(this, &Core::displayBinLogMessage, this, &Core::displayBinLogMessagePrivate);
 
-    if (m_splash && m_splash->hasEventLoop()) {
+    if (m_splash && (m_splash->hasEventLoop() || m_splash->welcomeDisplayed())) {
         Q_EMIT mainWindowReady();
     } else if (m_splash == nullptr || !m_splash->welcomeDisplayed()) {
         QMetaObject::invokeMethod(pCore->projectManager(), "slotLoadOnOpen", Qt::QueuedConnection);
@@ -571,7 +583,6 @@ void Core::startFromGuessedProfile(QString descriptiveString, QString fps, bool
 
     KdenliveSettings::setVideotracks(vTracks);
     KdenliveSettings::setAudiotracks(aTracks);
-    m_splash->deleteLater();
     m_mainWindow->show();
     QMetaObject::invokeMethod(pCore->projectManager(), "slotLoadOnOpen", Qt::QueuedConnection);
 }
